require 'uu/os/rest/dto'
require 'uu/os/uesuri'

module UU
  module OS

    module Cast
      class CastHistoryAttributes < UU::OS::REST::DTO

        # The subject where the subjects are cast, identified by UESURI. If the subjectUri has been deleted, then the value contains a canonical UESURI (without codes) instead of a normalized UESURI (with codes). Never nil.
        attr_accessor :subject_uri

        # Name of the subject where the subjects are cast. If the subjectUri has been deleted, then the value contains a name that was set at cast creation. Never nil.
        attr_accessor :subject_name

        # Code of the subject where the subjects are cast. If the subjectUri has been deleted, then the value contains a code that was set at cast creation. Never nil.
        attr_accessor :subject_code
        
        # Type of the subject where the subjects are cast. Never nil.
        #
        # @see UU::OS::Cast::CastSubjectType
        attr_accessor :subject_type
        
        # The subject cast in the subjectUri, identified by UESURI. If the castSubjectUri has been deleted, then the value contains a canonical UESURI (without codes) instead of a normalized UESURI (with codes). Never nil.
        attr_accessor :cast_subject_uri
        
        # Name of the subject cast in the subjectUri. If the castSubjectUri has been deleted, then the value contains a name that was set at cast creation. Never nil.
        attr_accessor :cast_subject_name

        # Code of the subject cast in the subjectUri. If the castSubjectUri has been deleted, then the value contains a code that was set at cast creation. Never nil.
        attr_accessor :cast_subject_code

        # Type of the subject cast in the subjectUri. Never nil.
        #
        # @see UU::OS::Cast::CastSubjectType
        attr_accessor :cast_subject_type

        # Direction of the cast. Never nil.
        #
        # @see UU::OS::Cast::CastLevel
        attr_accessor :level
        
        # Cast creation stamp. Never nil.
        attr_accessor :cast_creation_stamp

        # Cast deletion stamp. Nil if the cast still exists.
        attr_accessor :cast_deletion_stamp
        
        # Specifies direction of the cast.
        #
        # @see UU::OS::Cast::CastDirection
        attr_accessor :cast_direction

        def subject_uri
          attributes[:subjectUri]
        end

        def subject_uri=(val)
          if val
            attributes[:subjectUri] = UU::OS::UESURI.new(val)
          else
            attributes[:subjectUri] = nil
          end
        end

        def cast_subject_uri
          attributes[:castSubjectUri]
        end

        def cast_subject_uri=(val)
          if val
            attributes[:castSubjectUri] = UU::OS::UESURI.new(val)
          else
            attributes[:castSubjectUri] = nil
          end
        end

        def level
          attributes[:level]
        end

        def level=(val)
          attributes[:level] = val
        end

        def subject_name
          attributes[:subjectName]
        end

        def subject_name=(val)
          attributes[:subjectName] = val
        end

        def subject_code
          attributes[:subjectCode]
        end

        def subject_code=(val)
          attributes[:subjectCode] = val
        end

        def cast_subject_name
          attributes[:castSubjectName]
        end

        def cast_subject_name=(val)
          attributes[:castSubjectName] = val
        end

        def cast_subject_code
          attributes[:castSubjectCode]
        end

        def cast_subject_code=(val)
          attributes[:castSubjectCode] = val
        end

        def cast_direction
          attributes[:castDirection]
        end

        def cast_direction=(val)
          attributes[:castDirection] = val
        end
        
        def cast_creation_stamp
          attributes[:castCreationStamp]
        end

        def cast_creation_stamp=(val)
          attributes[:castCreationStamp] = val
        end
        
        def cast_deletion_stamp
          attributes[:castDeletionStamp]
        end

        def cast_deletion_stamp=(val)
          attributes[:castDeletionStamp] = val
        end
        
        def cast_subject_type
          attributes[:castSubjectType]
        end

        def cast_subject_type=(val)
          attributes[:castSubjectType] = val
        end
        
        def subject_type
          attributes[:subjectType]
        end

        def subject_type=(val)
          attributes[:subjectType] = val
        end

      end
    end

  end

end
