require 'uu/os/rest/dto'
require 'uu/os/uesuri'


module UU
  module OS

    module Folder
      
      class FolderEntryAttributes < UU::OS::REST::DTO

        # Code of the folder.
        attr_accessor :code

        # Name of the folder.
        attr_accessor :name

        # Description of the folder.
        attr_accessor :description

        # UESURI of the folder.
        attr_accessor :uri

        # UESURI of the referenced artifact from the shortcut. Null in case the entry is not of type SHORTCUT.
        attr_accessor :artifact_uri

        # Type of the entry.
        #
        # @see UU::OS::Folder::FolderEntryType
        attr_accessor :type

        # True if the folder entry is a container (folder, org.unit, territory, etc.)
        attr_accessor :container

        # True if the folder entry is a shortcut
        attr_accessor :shortcut

        # UESURI of the entity type of the folder entry. Never null.
        attr_accessor :entity_type_uri
        
        def code
          attributes[:code]
        end

        def code=(val)
          attributes[:code] = val
        end

        def name
          attributes[:name]
        end

        def name=(val)
          attributes[:name] = val
        end

        def description
          attributes[:description]
        end

        def description=(val)
          attributes[:description] = val
        end

        def uri
          attributes[:uri]
        end

        def uri=(val)
          if val
            attributes[:uri] = UU::OS::UESURI.new(val)
          else
            attributes[:uri] = nil
          end
        end

        def artifact_uri
          attributes[:artifactUri]
        end

        def artifact_uri=(val)
          if val
            attributes[:artifactUri] = UU::OS::UESURI.new(val)
          else
            attributes[:artifactUri] = nil
          end
        end

        def type
          attributes[:type]
        end

        def type=(val)
          attributes[:type] = val
        end

        def shortcut
          attributes[:shortcut]
        end

        def shortcut=(val)
          attributes[:shortcut] = val
        end

        def container
          attributes[:container]
        end

        def container=(val)
          attributes[:container] = val
        end

        def entity_type_uri
          attributes[:entityTypeUri]
        end

        def entity_type_uri=(val)
          if val
            attributes[:entityTypeUri] = UU::OS::UESURI.new(val)
          else
            attributes[:entityTypeUri] = nil
          end
        end

      end
    end

  end
end
