require 'uu/os/rest/dto'
require 'uu/os/uesuri'

module UU
  module OS
    module MetaUseCaseRealization
      # Meta Use Case Realization Set Attributes DTO.
      # @deprecated Use {UU::OS::MetaVisualUseCase::MetaVisualUseCaseSetAttributes} instead.
      class MetaUseCaseRealizationSetAttributes < UU::OS::REST::DTO

        # The new name of the meta use case realization. When nil is set, the name is not modified.
        attr_accessor :name

        # The new code of the meta use case realization. When nil is set, the code is not modified.
        # When blank string is set, the code is generated automatically using the system
        # sequence. The code must be unique in a given territory, otherwise the setAttributes
        # command fails.
        attr_accessor :code

        # The new description of the meta use case realization. When nil is set, the description
        # is not modified.
        attr_accessor :description

        # The new security level of the meta use case realization. When nil is set, the security
        # level is not modified. When user is setting the meta use case realization template
        # security level higher than the user's security clearance, the setAttributes
        # command fails.
        attr_accessor :security_level

        # UESURI of the new meta use case realization's icon. When nil is set, the icon is
        # not modified. If nil UESURI ("ues:{[-1]}:{[-1]}:") is set, the meta use case
        # realization icon is removed and the meta use case realization uses icon from its
        # meta use case realization.
        #
        # @example Allowed format of icon URI:
        #   ues:#{system}:#{ues_v5.core_v1.codetable_v1.base_v1.CodeTable_Icons}:#{CODE_OF_ICON}
        #
        # @example An example of icon URI:
        #   ues:#{system}:#{ues_v5.core_v1.codetable_v1.base_v1.CodeTable_Icons}:#{ART_077}
        attr_accessor :icon_uri

        # Specifies new default name of the created use case realization according to meta
        # use case realization (specified in sourceMetaArtifactUri). When nil is set,
        # the default name is not modified.
        attr_accessor :default_name

        # Specifies new default code of the created use case realization according to meta
        # use case realization (specified in sourceMetaArtifactUri). When nil is set,
        # the default code is not modified.
        attr_accessor :default_code

        # Specifies new default security level of the created use case realization according
        # to meta use case realization (specified in sourceMetaArtifactUri). When nil
        # is set, the default security is not modified.
        attr_accessor :default_security_level

        # Specifies new default icon of the created use case realization according to meta
        # use case realization (specified in metaArtifactUri). When nil is set,the default
        # icon is not modified.
        #
        # @example Allowed format of icon URI:
        #   ues:#{system}:#{ues_v5.core_v1.codetable_v1.base_v1.CodeTable_Icons}:#{CODE_OF_ICON}
        #
        # @example An example of icon URI:
        #   ues:#{system}:#{ues_v5.core_v1.codetable_v1.base_v1.CodeTable_Icons}:#{ART_077}
        attr_accessor :default_icon_uri
        def name 
          attributes[:name]
        end

        def name=(val) 
          attributes[:name] = val
        end

        def code 
          attributes[:code]
        end

        def code=(val) 
          attributes[:code] = val
        end

        def description 
          attributes[:description]
        end

        def description=(val) 
          attributes[:description] = val
        end

        def security_level 
          attributes[:securityLevel]
        end

        def security_level=(val) 
          attributes[:securityLevel] = val
        end

        def icon_uri 
          attributes[:iconUri]
        end

        def icon_uri=(val) 
          if val
            attributes[:iconUri] = UU::OS::UESURI.new(val)
          else
            attributes[:iconUri] = nil
          end
        end

        def default_name 
          attributes[:defaultName]
        end

        def default_name=(val) 
          attributes[:defaultName] = val
        end

        def default_code 
          attributes[:defaultCode]
        end

        def default_code=(val) 
          attributes[:defaultCode] = val
        end

        def default_security_level 
          attributes[:defaultSecurityLevel]
        end

        def default_security_level=(val) 
          attributes[:defaultSecurityLevel] = val
        end

        def default_icon_uri 
          attributes[:defaultIconUri]
        end

        def default_icon_uri=(val) 
          if val
            attributes[:defaultIconUri] = UU::OS::UESURI.new(val)
          else
            attributes[:defaultIconUri] = nil
          end
        end

      end
    end

  end
end
