require 'uu/os/rest/dto'
require 'uu/os/uesuri'


module UU
  module OS
    module Property

      class PropertyCollectionAttributes < UU::OS::REST::DTO

        # Normalize UESURI of the property collection. Never null.
        attr_accessor :uri

        # Name of the property collection. Never null.
        attr_accessor :name

        # Code of the property collection. Never null.
        attr_accessor :code

        # Description of the property collection
        attr_accessor :description

        # Normalized UESURI of the artifact or of the property collection where the property
        # collection is located. Never null.
        attr_accessor :parent_node_uri

        # UESURI of the entity type of the artifact (see @{cz.ues.platform.sysc.entitytype.UESEntityType}
        # for more info). It is the other artifact, the one different from the main entity.
        # More precisely it is the referenced artifact in case of outgoing reference, the
        # referencing artifact in case of incoming reference.
        attr_accessor :entity_type_uri

        # Version of the property collection.
        attr_accessor :version


        def uri
          attributes[:uri]
        end

        def uri=(val)
          if val
            attributes[:uri] = UU::OS::UESURI.new(val)
          else
            attributes[:uri] = nil
          end
        end

        def name
          attributes[:name]
        end

        def name=(val)
          attributes[:name] = val
        end

        def code
          attributes[:code]
        end

        def code=(val)
          attributes[:code] = val
        end

        def description
          attributes[:description]
        end

        def description=(val)
          attributes[:description] = val
        end

        def parent_node_uri
          attributes[:parentNodeUri]
        end

        def parent_node_uri=(val)
          if val
            attributes[:parentNodeUri] = UU::OS::UESURI.new(val)
          else
            attributes[:parentNodeUri] = nil
          end
        end

        def entity_type_uri
          attributes[:entityTypeUri]
        end

        def entity_type_uri=(val)
          if val
            attributes[:entityTypeUri] = UU::OS::UESURI.new(val)
          else
            attributes[:entityTypeUri] = nil
          end
        end

        def version
          attributes[:version]
        end

        def version=(val)
          attributes[:version] = val
        end

      end

    end
  end
end
